%define         majornum        4
%define         libname         %mklibname %{name} %{majornum}
%define         develname       %mklibname %{name} -d

%define         gccinstalldir   %(LC_ALL=C %__cc --print-search-dirs | grep install | %__awk '{print $2}')
%define         fincludedir     %{gccinstalldir}/finclude

Name:           aspic
Version:        1.5.3
Release:        %mkrel 2
Summary:        A scientific library dedicated to inflationary cosmology
License:        GPLv3+
Group:          Sciences/Astronomy

URL:            https://curl.irmp.ucl.ac.be/~chris/aspic.html
Source0:        https://curl.irmp.ucl.ac.be/~chris/upload/patches/aspic/aspic-%{version}.tar.gz
Patch0:         aspic-1.5.3-prec32b.patch

BuildRequires:  gcc-c++
BuildRequires:  gcc-gfortran
%ifarch %{ix86} x86_64
BuildRequires:  quadmath-devel
%endif
BuildRequires:  libgomp-devel


%description
Aspic is a collection of fast modern Fortran routines for computing
various observable quantities used in Cosmology from definite single
field inflationary models. It is distributed as a scientific library
and aims at providing an efficient, extendable and accurate way of
comparing theoretical inflationary predictions with cosmological data.


%package -n %{libname}
License:        GPLv3+
Summary:        The Aspic Fortran library
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}

%description -n %{libname}
Aspic is a collection of fast modern Fortran routines for computing
various observable quantities used in Cosmology from definite single
field inflationary models. It is distributed as a scientific library
and aims at providing an efficient, extendable and accurate way of
comparing theoretical inflationary predictions with cosmological data.


%package -n %{develname}
License:        GPLv3+
Summary:        Headers and modules for the Fortran Aspic libraries
Group:          Development/Other
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}

%description -n %{develname}
%{summary}.


%prep

%setup -q
%autopatch -p1



%build

if [ ! -d build-std ]; then
        mkdir build-std
fi
pushd build-std
CONFIGURE_TOP=.. %configure \
                    --includedir=%{fincludedir}
%make_build
popd

%ifarch %{ix86} x86_64
if [ ! -d build-quad ]; then
        mkdir build-quad
fi
pushd build-quad
CONFIGURE_TOP=.. %configure \
                    --includedir=%{fincludedir} \
                    --enable-quad-precision
%make_build
popd
%endif




%check
%make_build check -C build-std
%ifarch %{ix86} x86_64
%make_build check -C build-quad
%endif




%install

pushd build-std
%make_install
popd

%ifarch %{ix86} x86_64
pushd build-quad
%make_install
popd
%endif

#nuke la files from libtools
find %{buildroot}%{_libdir} -name *.la -delete
find %{buildroot}%{_libdir} -name *.a -delete


%files -n %{libname}
%doc COPYING AUTHORS README NEWS
%{_libdir}/libaspic.so.%{majornum}{,.*}
%ifarch %{ix86} x86_64
%{_libdir}/libaspicq.so.%{majornum}{,.*}
%endif
%{_mandir}/man3/*.3*


%files -n %{develname}
%doc ChangeLog TODO
%{_libdir}/libaspic.so
%dir %{fincludedir}/aspic
%{fincludedir}/aspic/*.mod
%{fincludedir}/aspic/aspic.h
%ifarch %{ix86} x86_64
%{_libdir}/libaspicq.so
%dir %{fincludedir}/aspicq
%{fincludedir}/aspicq/*.mod
%{fincludedir}/aspicq/aspicq.h
%endif



%changelog
* Thu Sep 05 2024 eatdirt <eatdirt> 1.5.3-2.mga10
+ Revision: 2093216
- Fix precision convertion on 32bits
- Update to version 1.5.3

* Thu Oct 26 2023 eatdirt <eatdirt> 1.5.2-1.mga10
+ Revision: 2001870
- Update to version 1.5.2

* Tue Oct 17 2023 eatdirt <eatdirt> 1.4.3.1-1.mga10
+ Revision: 1998210
- Update to version 1.4.3.1

* Thu Apr 20 2023 eatdirt <eatdirt> 1.4.1-1.mga9
+ Revision: 1953672
- Update to version 1.4.1

* Thu Aug 25 2022 eatdirt <eatdirt> 1.2.2-1.mga9
+ Revision: 1880344
- Fix build on i586
- Update to version 1.2.2

* Tue Mar 15 2022 umeabot <umeabot> 1.0.1-7.mga9
+ Revision: 1792745
- Mageia 9 Mass Rebuild
+ pterjan <pterjan>
- Remove usage of obsolete macros (https://github.com/rpm-software-management/rpm/issues/1211)

* Thu Mar 12 2020 tmb <tmb> 1.0.1-6.mga8
+ Revision: 1555902
- rebuild for gcc 9.3.0 final with major-only version in file paths

* Sun Mar 08 2020 tmb <tmb> 1.0.1-5.mga8
+ Revision: 1554876
- rebuild for gcc 9.3.0

* Sat Feb 15 2020 umeabot <umeabot> 1.0.1-4.mga8
+ Revision: 1525442
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Apr 17 2019 eatdirt <eatdirt> 1.0.1-3.mga7
+ Revision: 1392361
- More fixing quadprecs
- Fix quadprec issue on i586
- Upgrade to vesion 1.0.1

* Fri Sep 21 2018 umeabot <umeabot> 0.3.3.7-4.mga7
+ Revision: 1294995
- Mageia 7 Mass Rebuild

* Tue Jul 31 2018 eatdirt <eatdirt> 0.3.3.7-3.mga7
+ Revision: 1246342
- Rebuild for new gfortran

* Thu Jul 05 2018 eatdirt <eatdirt> 0.3.3.7-2.mga7
+ Revision: 1241866
- Fix too high precision on integer for i586
- Update to version 0.3.3.7
- Rebuild for new gcc-5.5.0 (#23281)

* Mon Sep 11 2017 tv <tv> 0.3.2-5.mga7
+ Revision: 1152753
- rebuild for new libgfortran

* Thu Aug 04 2016 eatdirt <eatdirt> 0.3.2-4.mga6
+ Revision: 1044456
- Rebuild for new gfortran (module versionning)
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Dec 10 2015 neoclust <neoclust> 0.3.2-2.mga6
+ Revision: 909332
- Add podd inside the %%ifarch

* Wed Aug 26 2015 eatdirt <eatdirt> 0.3.2-1.mga6
+ Revision: 869731
- Upgrade to version 0.3.2

* Wed Oct 15 2014 umeabot <umeabot> 0.3.1-5.mga5
+ Revision: 739969
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.3.1-4.mga5
+ Revision: 677997
- Mageia 5 Mass Rebuild

* Tue Feb 25 2014 eatdirt <eatdirt> 0.3.1-3.mga5
+ Revision: 597217
- Add provides, update url

* Mon Oct 21 2013 umeabot <umeabot> 0.3.1-2.mga4
+ Revision: 539693
- Mageia 4 Mass Rebuild

* Tue Oct 08 2013 eatdirt <eatdirt> 0.3.1-1.mga4
+ Revision: 492802
- imported package aspic

